{
  'target_defaults': {
    'variables': {
      'deps': [
        'dbus-1',
        'libchrome-<(libbase_ver)',
        'libchromeos-<(libbase_ver)',
      ],
    },
    'include_dirs': ['.'],
  },
  'targets': [
    {
      'target_name': 'libbuffet-<(libbase_ver)',
      'type': 'shared_library',
      'sources': [
        'libbuffet/command.cc',
        'libbuffet/command_listener.cc',
        'libbuffet/dbus_constants.cc',
        'libbuffet/private/command_property_set.cc',
      ],
      'actions': [
        {
          'action_name': 'generate-buffet-proxies',
          'inputs': [
            'dbus_bindings/org.chromium.Buffet.Command.xml',
            'dbus_bindings/org.chromium.Buffet.Manager.xml',
          ],
          'outputs': [
            '<(SHARED_INTERMEDIATE_DIR)/include/buffet/dbus-proxies.h',
          ],
          'action': [
            '<!(which generate-chromeos-dbus-bindings)',
            '>@(_inputs)',
            '--proxy=>(_outputs)'
          ],
          'hard_dependency': 1,
        },
      ],
      'includes': ['../common-mk/deps.gypi'],
    },
    {
      'target_name': 'buffet_common',
      'type': 'static_library',
      'variables': {
        'dbus_adaptors_out_dir': 'include/buffet',
      },
      'sources': [
        'commands/command_definition.cc',
        'commands/command_dictionary.cc',
        'commands/command_instance.cc',
        'commands/command_manager.cc',
        'commands/command_queue.cc',
        'commands/dbus_command_dispatcher.cc',
        'commands/dbus_command_proxy.cc',
        'commands/cloud_command_proxy.cc',
        'commands/object_schema.cc',
        'commands/prop_constraints.cc',
        'commands/prop_types.cc',
        'commands/prop_values.cc',
        'commands/schema_constants.cc',
        'commands/schema_utils.cc',
        'device_registration_info.cc',
        'dbus_bindings/org.chromium.Buffet.Command.xml',
        'dbus_bindings/org.chromium.Buffet.Manager.xml',
        'manager.cc',
        'storage_impls.cc',
        'states/error_codes.cc',
        'states/state_change_queue.cc',
        'states/state_manager.cc',
        'states/state_package.cc',
        'utils.cc',
      ],
      'includes': ['../common-mk/generate-dbus-adaptors.gypi'],
    },
    {
      'target_name': 'buffet',
      'type': 'executable',
      'dependencies': [
        'buffet_common',
        'libbuffet-<(libbase_ver)',
      ],
      'sources': [
        'main.cc',
      ],
    },
    {
      'target_name': 'buffet_test_daemon',
      'type': 'executable',
      'dependencies': [
        'libbuffet-<(libbase_ver)',
      ],
      'sources': [
        'test_daemon/main.cc',
      ],
    },
    {
      'target_name': 'buffet_client',
      'type': 'executable',
      'dependencies': [
        'libbuffet-<(libbase_ver)',
      ],
      'sources': [
        'buffet_client.cc',
      ],
    },
  ],
  'conditions': [
    ['USE_test == 1', {
      'targets': [
        {
          'target_name': 'buffet_testrunner',
          'type': 'executable',
          'dependencies': [
            'buffet_common',
            'libbuffet-<(libbase_ver)',
          ],
          'variables': {
            'deps': [
              'libchrome-test-<(libbase_ver)',
              'libchromeos-test-<(libbase_ver)',
            ],
          },
          'includes': ['../common-mk/common_test.gypi'],
          'sources': [
            'buffet_testrunner.cc',
            'commands/command_definition_unittest.cc',
            'commands/command_dictionary_unittest.cc',
            'commands/command_instance_unittest.cc',
            'commands/command_manager_unittest.cc',
            'commands/command_queue_unittest.cc',
            'commands/dbus_command_dispatcher_unittest.cc',
            'commands/dbus_command_proxy_unittest.cc',
            'commands/object_schema_unittest.cc',
            'commands/schema_utils_unittest.cc',
            'commands/unittest_utils.cc',
            'device_registration_info_unittest.cc',
            'states/state_change_queue_unittest.cc',
            'states/state_manager_unittest.cc',
            'states/state_package_unittest.cc',
          ],
        },
      ],
    }],
  ],
}
